pub struct Hms(pub TimeDelta);Expand description
A utility for deserializing and displaying durations in HH::MM::SS format.
Tuple Fields
0: TimeDeltaTrait Implementations
Sourceimpl Debug for Hms
The Debug and Display impls are the same for Hms as I never want to see the TimeDelta representation.
impl Debug for Hms
The Debug and Display impls are the same for Hms as I never want to see the TimeDelta representation.
impl Copy for Hms