pub struct PartialCdr {Show 13 fields
pub currency_code: Code,
pub party_id: Option<CpoId>,
pub start_date_time: DateTime<Utc>,
pub end_date_time: DateTime<Utc>,
pub total_energy: Option<Kwh>,
pub total_charging_duration: Option<TimeDelta>,
pub total_idle_duration: Option<TimeDelta>,
pub total_cost: Option<Price>,
pub total_energy_cost: Option<Price>,
pub total_fixed_cost: Option<Price>,
pub total_idle_duration_cost: Option<Price>,
pub total_charging_duration_cost: Option<Price>,
pub charging_periods: Vec<ChargingPeriod>,
}Expand description
A partial CDR generated by the cdr_from_tariff function.
The CDR is partial as not all required fields are set as the cdr_from_tariff function
does not know anything about the EVSE location or the token used to authenticate the chargesession.
- See: OCPI spec 2.2.1: CDR.
- See: OCPI spec 2.1.1: Tariff.
Fields
currency_code: CodeISO-3166 alpha-2 country code of the CPO that ‘owns’ this CDR.
party_id: Option<CpoId>The five character ID of the CPO that ‘owns’ this CDR.
The first two characters are the ISO-3166 alpha-2 country code of the CPO. The remaining three characters are the ISO-15118 ID of the CPO.
None if a v211 tariff was used to generate the CDR.
The v211 tariff does not define a country code or party_id field.
start_date_time: DateTime<Utc>Start timestamp of the charging session.
end_date_time: DateTime<Utc>End timestamp of the charging session.
total_energy: Option<Kwh>Total energy charged, in kWh.
total_charging_duration: Option<TimeDelta>Total duration charging.
Some if the charging happened during the session.
total_idle_duration: Option<TimeDelta>Total duration not charging.
Some if there was idle time during the session.
total_cost: Option<Price>Total cost of this transaction.
total_energy_cost: Option<Price>Total cost related to the energy dimension.
total_fixed_cost: Option<Price>Total cost of the flat dimension.
total_idle_duration_cost: Option<Price>Total cost related to the idle time dimension.
total_charging_duration_cost: Option<Price>Total cost related to the charging time dimension.
charging_periods: Vec<ChargingPeriod>List of charging periods that make up this charging session. A session should consist of 1 or more periods, where each period has a different relevant Tariff.