pub enum RemovalError {
Root,
UnknownElement(ElemId),
}Expand description
Why a set of elements could not be resolved to removal spans.
Variants
Root
The root element has no parent, so removing it would leave no document behind.
UnknownElement(ElemId)
No element in this document has this id.