pub enum TokenType {
BooleanFalse,
BooleanTrue,
BracketClose,
BracketOpen,
Colon,
Comma,
CurlyClose,
CurlyOpen,
Invalid,
Null,
Number,
String,
}Expand description
Define our own TokenType so Clone can be defined on it.
This can be removed when json_tools::TokenType impls Clone.
Variants
BooleanFalse
false.
BooleanTrue
true.
BracketClose
].
BracketOpen
[.
Colon
:.
Comma
,.
CurlyClose
}.
CurlyOpen
{.
Invalid
The type of the token could not be identified. Should be removed if this lexer is ever to be feature complete.
Null
null.
Number
A Number, like 1.1234 or 123 or -0.0 or -1 or .0 or ..
String
A JSON string, like "foo".