pub struct Token {
pub kind: TokenType,
pub span: Span,
}Expand description
A lexical token, identifying its kind and span.
We define our own Token as the json_tools::Token defines a Buffer that can be heap allocated
or a Span. We only use the Span variant.
Our Token can also impl Copy and Clone as the size and semantics are acceptable.
Fields
kind: TokenTypeThe exact type of the token.
span: SpanThe span allows the caller to reference back into the source byte stream to obtain the string making up the token.