pub struct Error { /* private fields */ }Expand description
A parse error produced when the input is not well-formed JSON.
Carries the byte offset and line/column position of the failure, and an
ErrorKind that describes what was wrong.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn byte_offset(&self) -> usize
pub fn byte_offset(&self) -> usize
Byte offset of the error location.
Sourcepub fn kind(&self) -> &ErrorKind
pub fn kind(&self) -> &ErrorKind
Return a reference to the details about the error that occurred.
Sourcepub fn into_kind(self) -> ErrorKind
pub fn into_kind(self) -> ErrorKind
Consume the Error and return the details about the error that occurred.
Sourcepub fn into_parts(self) -> (usize, ErrorKind)
pub fn into_parts(self) -> (usize, ErrorKind)
Consume the Error and return the byte offset of the error location and the details of the
error that occurred.