pub enum Warning {
ExclusiveVatGreaterThanInclusive,
Number(Warning),
Rejected,
}Expand description
The warnings that can happen when parsing or linting a Price.
Variants
ExclusiveVatGreaterThanInclusive
The excl_vat field is greater than the incl_vat field.
Number(Warning)
Both the excl_vat and incl_vat fields should be valid numbers.
Rejected
A feature rejected the schema IR for a Price because a required field was missing or
invalid. The located cause is reported by the schema validation warnings; this is a
content-free marker (see warning::Rejected).