pub struct DisplayCurrency<'a> { /* private fields */ }Expand description
A Display object for displaying Money with an associated currency.
Note: The placement of the currency symbol is always before the amount. The locale is not used to determine symbol position.