pub struct Component { /* private fields */ }Expand description
A Price Component describes how a certain amount of a certain dimension being consumed translates into an amount of money owed.
Implementations