pub struct Total<TCdr, TCalc = TCdr> {
pub cdr: TCdr,
pub calculated: TCalc,
}Expand description
A related source and calculated pair of total amounts.
This is used to express the source and calculated amounts for the total fields of a CDR.
total_costtotal_fixed_costtotal_energytotal_energy_costtotal_timetotal_time_costtotal_parking_timetotal_parking_cost
Fields
cdr: TCdrThe source value from the CDR.
calculated: TCalcThe value calculated by the cdr::price function.