pub enum Warning {
CantInferTimezoneFromCountry(&'static str),
ContainsEscapeCodes,
Country(Warning),
Decode(Warning),
InvalidLocationType,
InvalidTimezone,
InvalidTimezoneType,
LocationCountryShouldBeAlpha3,
NoLocationCountry,
NoLocation,
ShouldBeAnObject,
V221CdrHasLocationField,
}Expand description
The warnings possible when parsing or linting an IANA timezone.
Variants
CantInferTimezoneFromCountry(&'static str)
A timezone can’t be inferred from the location’s country.
ContainsEscapeCodes
Neither the timezone or country field require char escape codes.
Country(Warning)
The CDR location is not a valid ISO 3166-1 alpha-3 code.
Decode(Warning)
The field at the path could not be decoded.
InvalidLocationType
The CDR location is not a String.
InvalidTimezone
The CDR location did not contain a valid IANA time-zone.
InvalidTimezoneType
The CDR timezone is not a String.
LocationCountryShouldBeAlpha3
The location.country field should be an alpha-3 country code.
The alpha-2 code can be converted into an alpha-3 but the caller should be warned.
NoLocationCountry
The CDR’s location has no country element and so the timezone can’t be inferred.
NoLocation
The CDR has no location element and so the timezone can’t be found or inferred.
ShouldBeAnObject
Both the CDR and tariff JSON should be an Object.
V221CdrHasLocationField
A v221 CDR is given but it contains a location field instead of a cdr_location as defined in the spec.