Verdict

Type Alias Verdict 

pub type Verdict<T, W> = Result<Caveat<T, W>, ErrorSet<W>>;
A Verdict is a standard Result with Warnings potentially issued for both the Ok and Err variants.

Aliased Type

pub enum Verdict<T, W> {
    Ok(Caveat<T, W>),
    Err(ErrorSet<W>),
}

Variants

1.0.0

Ok(Caveat<T, W>)

Contains the success value

1.0.0

Err(ErrorSet<W>)

Contains the error value