CaveatDeferred

Struct CaveatDeferred 

pub struct CaveatDeferred<T, W: Warning> { /* private fields */ }
A value that may have associated Warnings.

This caveat is considered deferred as the warning still need to be associated with a json::Element to become Warnings.

Even though the value has been created there may be certain caveats you should be aware of before using it.

NOTE: The deferred types are used to avoid passing json::Element references to functions just to create Warnings.

Implementations

Source

impl<T, W> CaveatDeferred<T, W>
where W: Warning,

pub fn into_parts(self) -> (T, SetDeferred<W>)

Return the value and any Warnings stored in the CaveatDeferred.

pub fn ignore_warnings(self) -> T

Return the value and drop any warnings contained within.