pub struct ErrorSetDeferred<W: Warning> { /* private fields */ }Expand description
A set of Warnings and a Warning that caused an operation to fail to be represented as an Error.
This set is transported through the system using a [VerdictDeferred]s Err variant.
This set is considered deferred as the Warnings need to be associated with a json::Element
to become Warnings.
NOTE: The deferred types are used to avoid passing json::Element references
to functions just to create Warnings.