Group

Struct Group 

pub struct Group<W: Warning> { /* private fields */ }
A group of warning Warnings associated with an Element.

This group is emitted from the IntoGroupByElem iterator. The warning Warnings are owned and so can be moved to another location.

Implementations

Source

impl<W> Group<W>
where W: Warning,

pub fn into_parts(self) -> (Element, Vec<W>)

Consume the Group and return the constituent parts.

pub fn to_parts(&self) -> (&Element, Vec<&W>)

Borrow the element and its Warnings.

pub fn warnings(&self) -> Vec<&W>

Borrow just the Warnings, without the element.

pub fn into_warnings(self) -> Vec<W>

Consume the group and return just the Warnings, discarding the element.