pub struct SetDeferred<W: Warning>(/* private fields */);Expand description
A set of Warnings transported through the system using a VerdictDeferred or CaveatDeferred.
This set is considered deferred as the Warnings need to be associated with a json::Element
to become Warnings.
NOTE: The deferred types are used to avoid passing json::Element references
to functions just to create Warnings.