pub struct Versioned<'buf> { /* private fields */ }Expand description
A json::Element that has been processed by either the infer_version or build
functions and has been identified as being a certain [Version].
Implementations
Sourceimpl<'buf> Versioned<'buf>
impl<'buf> Versioned<'buf>
Sourcepub fn into_doc(self) -> Document<'buf>
pub fn into_doc(self) -> Document<'buf>
Return the inner json::Document and discard the version info.
Sourcepub fn as_element(&self) -> &Element<'buf>
pub fn as_element(&self) -> &Element<'buf>
Return the inner json::Element and discard the version info.
Sourcepub fn as_doc(&self) -> &Document<'buf>
pub fn as_doc(&self) -> &Document<'buf>
Return the inner json::Document and discard the version info.
Sourcepub fn as_json_str(&self) -> &'buf str
pub fn as_json_str(&self) -> &'buf str
Return the inner JSON str and discard the version info.