pub enum PendingStr<'buf> {
NoEscapes(&'buf str),
HasEscapes(EscapeStr<'buf>),
}Expand description
Marks a &str as having escapes or not.
Variants
NoEscapes(&'buf str)
The &str has no escapes and can be used as is.
HasEscapes(EscapeStr<'buf>)
The &str has escape chars and needs to be unescaped before trying to parse into another form.