pub enum Warning {
Show 17 variants
Country(Warning),
Currency(Warning),
DateTime(Warning),
Decode(Warning),
Duration(Warning),
Enum(Warning),
FieldInvalidType {
expected_type: ValueKind,
},
FieldInvalidValue {
value: String,
message: Cow<'static, str>,
},
FieldRequired {
field_name: Cow<'static, str>,
},
Money(Warning),
ReservationElementSkipped,
TotalCostClampedToMin,
TotalCostClampedToMax,
NoElements,
NotActive,
Number(Warning),
String(Warning),
}Variants
Country(Warning)
The CDR location is not a valid ISO 3166-1 alpha-3 code.
Currency(Warning)
DateTime(Warning)
Decode(Warning)
Duration(Warning)
Enum(Warning)
FieldInvalidType
A field in the tariff doesn’t have the expected type.
FieldInvalidValue
A field in the tariff doesn’t have the expected value.
Fields
FieldRequired
The given field is required.
Money(Warning)
ReservationElementSkipped
A tariff element has a reservation restriction (RESERVATION or RESERVATION_EXPIRES).
Such elements apply only to reservation sessions, not to regular charging sessions. Because reservation pricing is not supported, the element is treated as permanently inactive.
TotalCostClampedToMin
The given tariff has a min_price set and the total_cost fell below it.
TotalCostClampedToMax
The given tariff has a max_price set and the total_cost exceeded it.
NoElements
The tariff has no Elements.
NotActive
The tariff is not active during the Cdr::start_date_time.
Number(Warning)
String(Warning)