Warning

Trait Warning 

pub trait Warning:
    Sized
    + Debug
    + Display
    + Send
    + Sync {
    // Required method
    fn id(&self) -> Id;
}
Each mod defines warnings for the type that it’s trying to parse or lint from a json::Element.

The Warning in the mod should impl this trait to take part in the Warning system.

Required Methods

fn id(&self) -> Id

Return the human readable identifier for the Warning.

This is used in the auto_test assertion system. Changing these strings may require updating output_price__cdr.json files.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Warning for Infallible

A FromSchema implementation that can never emit a warning uses std::convert::Infallible as its Warning type. The type is uninhabited, so every method is unreachable.

Source

fn id(&self) -> Id

Implementors

Source

impl Warning for Error

Source

impl Warning for ocpi_tariffs::country::Warning

Source

impl Warning for ocpi_tariffs::currency::Warning

Source

impl Warning for ocpi_tariffs::datetime::Warning

Source

impl Warning for ocpi_tariffs::duration::Warning

Source

impl Warning for ocpi_tariffs::enumeration::Warning

Source

impl Warning for ocpi_tariffs::generate::Warning

Source

impl Warning for ocpi_tariffs::json::decode::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::v2x::time::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::v2x::elements::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::v2x::price_components::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::v2x::restrictions::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::v2x::weekday::Warning

Source

impl Warning for ocpi_tariffs::lint::tariff::Warning

Source

impl Warning for ocpi_tariffs::money::Warning

Source

impl Warning for ocpi_tariffs::number::Warning

Source

impl Warning for ocpi_tariffs::price::Warning

Source

impl Warning for ocpi_tariffs::schema::Warning

Source

impl Warning for ocpi_tariffs::string::Warning

Source

impl Warning for ocpi_tariffs::tariff::Warning

Source

impl Warning for ocpi_tariffs::timezone::Warning