pub trait Warning:
Sized
+ Debug
+ Display
+ Send
+ Sync {
// Required method
fn id(&self) -> Id;
}Expand description
Each mod defines warnings for the type that it’s trying to parse or lint from a json::Element.
The Warning in the mod should impl this trait to take part in the Warning system.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Warning for Infallible
A FromSchema implementation that can never emit a warning uses std::convert::Infallible
as its Warning type. The type is uninhabited, so every method is unreachable.
impl Warning for Infallible
A FromSchema implementation that can never emit a warning uses std::convert::Infallible
as its Warning type. The type is uninhabited, so every method is unreachable.