Element

Struct Element 

pub struct Element { /* private fields */ }
A representation of a JSON element that satisfies the needs of most consumers of a Warning.

This representation avoids the complexity of needing to provide a 'buf lifetime to the json::Element. This would complicate all warnings types with that lifetime.

A consumer of warnings wants to group them by [json::ElemId] using Warning::group_by_elem and then display or report the warnings by path.

The linter report also wants to highlight the source JSON that a warning refers too.

Implementations

Source

impl Element

pub fn span(&self) -> Span

pub fn path(&self) -> &Path

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 67)
64fn print_error(error: &warning::Error<generate::Warning>) {
65    eprintln!(
66        "ERR: Unable to generate CDR due to error at path `{}`: {}",
67        error.element().path(),
68        error.warning()
69    );
70}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 65)
62fn print_pricing_error(error: &warning::Error<price::Warning>) {
63    eprintln!(
64        "ERR: Unable to price CDR due to error at path `{}`: {}",
65        error.element().path(),
66        error.warning()
67    );
68}
examples/price_cdr_with_unknown_version.rs (line 92)
89fn print_timezone_error(error: &warning::Error<timezone::Warning>) {
90    eprintln!(
91        "ERR: Unable to find timezone due to error at path `{}`: {}",
92        error.element().path(),
93        error.warning()
94    );
95}
96
97/// Print the `timezone::Warning`s to `stderr`.
98fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
99    if warnings.is_empty() {
100        return;
101    }
102
103    eprintln!(
104        "WARN: {} warnings from the timezone search",
105        warnings.len_warnings()
106    );
107
108    eprintln!(
109        "WARN: {} warnings from the timezone search:\n {}",
110        warnings.len_warnings(),
111        warning::SetWriter::new(warnings)
112    );
113}
114
115/// Print the `price::Warning` that halted the process to `stderr`.
116fn print_pricing_error(error: &warning::Error<price::Warning>) {
117    eprintln!(
118        "ERR: Unable to price CDR due to error at path `{}`: {}",
119        error.element().path(),
120        error.warning()
121    );
122}
pub fn into_parts(self) -> (Span, Path)