Error

Struct Error 

pub struct Error<W: Warning> { /* private fields */ }
The warning that caused an operation to fail.

The Warning is referred to by the json::Elements path as a String.

Implementations

Source

impl<W: Warning> Error<W>

pub fn warning(&self) -> &W

Return reference to the Warning.

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 67)
63fn print_error(error: &warning::Error<generate::Warning>) {
64    eprintln!(
65        "ERR: Unable to generate CDR due to error at path `{}`: {}",
66        error.element().path(),
67        error.warning()
68    );
69}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 65)
61fn print_pricing_error(error: &warning::Error<price::Warning>) {
62    eprintln!(
63        "ERR: Unable to price CDR due to error at path `{}`: {}",
64        error.element().path(),
65        error.warning()
66    );
67}
examples/price_cdr_with_unknown_version.rs (line 92)
88fn print_timezone_error(error: &warning::Error<timezone::Warning>) {
89    eprintln!(
90        "ERR: Unable to find timezone due to error at path `{}`: {}",
91        error.element().path(),
92        error.warning()
93    );
94}
95
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97    if warnings.is_empty() {
98        return;
99    }
100
101    eprintln!(
102        "WARN: {} warnings from the timezone search",
103        warnings.len_warnings()
104    );
105
106    eprintln!(
107        "WARN: {} warnings from the timezone search:\n {}",
108        warnings.len_warnings(),
109        warning::SetWriter::new(warnings)
110    );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114    eprintln!(
115        "ERR: Unable to price CDR due to error at path `{}`: {}",
116        error.element().path(),
117        error.warning()
118    );
119}
pub fn into_warning(self) -> W

Consume the Error and return the Warning.

pub fn element(&self) -> &Element

Return a reference to the Element that caused the Warning.

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 66)
63fn print_error(error: &warning::Error<generate::Warning>) {
64    eprintln!(
65        "ERR: Unable to generate CDR due to error at path `{}`: {}",
66        error.element().path(),
67        error.warning()
68    );
69}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 64)
61fn print_pricing_error(error: &warning::Error<price::Warning>) {
62    eprintln!(
63        "ERR: Unable to price CDR due to error at path `{}`: {}",
64        error.element().path(),
65        error.warning()
66    );
67}
examples/price_cdr_with_unknown_version.rs (line 91)
88fn print_timezone_error(error: &warning::Error<timezone::Warning>) {
89    eprintln!(
90        "ERR: Unable to find timezone due to error at path `{}`: {}",
91        error.element().path(),
92        error.warning()
93    );
94}
95
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97    if warnings.is_empty() {
98        return;
99    }
100
101    eprintln!(
102        "WARN: {} warnings from the timezone search",
103        warnings.len_warnings()
104    );
105
106    eprintln!(
107        "WARN: {} warnings from the timezone search:\n {}",
108        warnings.len_warnings(),
109        warning::SetWriter::new(warnings)
110    );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114    eprintln!(
115        "ERR: Unable to price CDR due to error at path `{}`: {}",
116        error.element().path(),
117        error.warning()
118    );
119}
pub fn parts(&self) -> (&W, &Element)

Return the constituent parts.

pub fn into_parts(self) -> (W, Element)

Consume the Cause and return the constituent parts.