pub struct Group<W: Warning> { /* private fields */ }Expand description
A group of warning Warnings associated with an Element.
This group is emitted from the IntoGroupByElem iterator.
The warning Warnings are owned and so can be moved to another location.
Implementations