Group

Struct Group 

pub struct Group<W: Warning> { /* private fields */ }
A group of warning Warnings associated with an Element.

This group is emitted from the IntoGroupByElem iterator. The warning Warnings are owned and so can be moved to another location.

Implementations

Source

impl<W> Group<W>
where W: Warning,

pub fn into_parts(self) -> (Element, Vec<W>)

pub fn to_parts(&self) -> (&Element, Vec<&W>)

pub fn warnings(&self) -> Vec<&W>

pub fn into_warnings(self) -> Vec<W>