pub struct IdPathMap<'set> {
pub total_warnings: usize,
pub total_elements: usize,
pub elements_filtered: usize,
pub warning_types_filtered: usize,
pub warnings: BTreeMap<Id, Vec<&'set str>>,
}Expand description
The outcome of calling the Set::id_path_map function.
Fields
total_warnings: usizetotal_elements: usizeThe total amount of json::Element paths in the source Set.
elements_filtered: usizeThe amount of json::Element paths filtered due to a Limit being set.
warning_types_filtered: usizeThe amount of Warning Ids filtered due to a Limit being set.
Note: This is not a count of how many warnings were filtered. It’s a count of how many
types of warnings were filtered. If seven excessive_precision warnings are filtered,
this counts as one type, as all the IDs that were filtered are the same.
warnings: BTreeMap<Id, Vec<&'set str>>The map of all Warning Ids mapped to the json::Element paths where they occurred.