Set

Struct Set 

pub struct Set<W: Warning>(/* private fields */);
A set of Warnings transported through the system using a Caveat.

Implementations

Source

impl<W: Warning> Set<W>

pub fn is_empty(&self) -> bool

Return true if the Warning set is empty.

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 72)
71fn print_warnings(warnings: &warning::Set<generate::Warning>) {
72    if warnings.is_empty() {
73        return;
74    }
75
76    eprintln!(
77        "WARN: {} warnings from the linting:\n {}",
78        warnings.len_warnings(),
79        warning::SetWriter::new(warnings)
80    );
81}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 70)
69fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
70    if warnings.is_empty() {
71        return;
72    }
73
74    eprintln!(
75        "WARN: {} warnings from the pricing:\n {}",
76        warnings.len_warnings(),
77        warning::SetWriter::new(warnings)
78    );
79}
examples/lint_tariff.rs (line 32)
31fn print_lint_warnings(warnings: &warning::Set<lint::tariff::Warning>) {
32    if warnings.is_empty() {
33        return;
34    }
35
36    eprintln!(
37        "WARN: {} warnings from the linting:\n {}",
38        warnings.len_warnings(),
39        warning::SetWriter::new(warnings)
40    );
41}
examples/price_cdr_with_unknown_version.rs (line 32)
6fn main() {
7    const CDR_JSON: &str = include_str!("data/cdr_time_and_parking_time.json");
8
9    // First the raw JSON should be parsed into a `cdr::Versioned` object.
10    // The `cdr::Report` returned from calling `cdr::parse` contains a `cdr::Versioned` object
11    // and a potential list of unexpected fields based on the OCPI v221 spec.
12    let cdr = cdr::parse(CDR_JSON).expect("Unable to parse CDR JSON");
13
14    // The guessed Version can be either certain or uncertain.
15    // In this case we discard the CDR object and try to convert it into a version.
16    // If the version is uncertain then fallback to presuming the CDR is v211.
17    let cdr = cdr.certain_or(Version::V211);
18
19    // The timezone can be inferred or found in the CDR, but a versioned CDR is required.
20    let timezone = match timezone::find_or_infer(&cdr) {
21        Ok(tz) => tz,
22        Err(err_set) => {
23            let (error, warnings) = err_set.into_parts();
24            eprintln!("Unable to infer timezone");
25            print_timezone_error(&error);
26            print_timezone_warnings(&warnings);
27            return;
28        }
29    };
30    let (timezone_source, warnings) = timezone.into_parts();
31
32    if !warnings.is_empty() {
33        print_timezone_warnings(&warnings);
34    }
35
36    // We don't care whether the timezone was found or inferred.
37    let timezone = timezone_source.into_timezone();
38    let report = cdr::parse_with_version(CDR_JSON, Version::V211).expect("Unable to parse CDR");
39    let cdr::ParseReport {
40        cdr,
41        unexpected_fields,
42    } = report;
43
44    if !unexpected_fields.is_empty() {
45        eprintln!("Strange... there are fields in the CDR that are not defined in the spec.");
46
47        for path in &unexpected_fields {
48            eprintln!("{path}");
49        }
50    }
51
52    let report = match cdr::price(&cdr, price::TariffSource::UseCdr, timezone) {
53        Ok(r) => r,
54        Err(set) => {
55            let (error, warnings) = set.into_parts();
56            print_pricing_error(&error);
57            print_pricing_warnings(&warnings);
58            return;
59        }
60    };
61
62    let (report, warnings) = report.into_parts();
63
64    print_pricing_warnings(&warnings);
65
66    // The various fields of the `price::Report` can be examined or converted to JSON.
67    let price::Report {
68        periods: _,
69        tariff_used: _,
70        tariff_reports: _,
71        timezone: _,
72        billed_energy: _,
73        billed_parking_time: _,
74        total_charging_time: _,
75        billed_charging_time: _,
76        total_cost: _,
77        total_fixed_cost: _,
78        total_time: _,
79        total_time_cost: _,
80        total_energy: _,
81        total_energy_cost: _,
82        total_parking_time: _,
83        total_parking_cost: _,
84        total_reservation_cost: _,
85    } = report;
86}
87
88fn print_timezone_error(error: &warning::Error<timezone::Warning>) {
89    eprintln!(
90        "ERR: Unable to find timezone due to error at path `{}`: {}",
91        error.element().path(),
92        error.warning()
93    );
94}
95
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97    if warnings.is_empty() {
98        return;
99    }
100
101    eprintln!(
102        "WARN: {} warnings from the timezone search",
103        warnings.len_warnings()
104    );
105
106    eprintln!(
107        "WARN: {} warnings from the timezone search:\n {}",
108        warnings.len_warnings(),
109        warning::SetWriter::new(warnings)
110    );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114    eprintln!(
115        "ERR: Unable to price CDR due to error at path `{}`: {}",
116        error.element().path(),
117        error.warning()
118    );
119}
120
121fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
122    if warnings.is_empty() {
123        return;
124    }
125
126    eprintln!(
127        "WARN: {} warnings from the linting:\n {}",
128        warnings.len_warnings(),
129        warning::SetWriter::new(warnings)
130    );
131}
pub fn len_elements(&self) -> usize

Return the amount of Elements in this set.

Each Element can have many Warnings associated with it.

pub fn len_warnings(&self) -> usize

Return the total amount of Warnings in this set for all Elements.

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 78)
71fn print_warnings(warnings: &warning::Set<generate::Warning>) {
72    if warnings.is_empty() {
73        return;
74    }
75
76    eprintln!(
77        "WARN: {} warnings from the linting:\n {}",
78        warnings.len_warnings(),
79        warning::SetWriter::new(warnings)
80    );
81}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 76)
69fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
70    if warnings.is_empty() {
71        return;
72    }
73
74    eprintln!(
75        "WARN: {} warnings from the pricing:\n {}",
76        warnings.len_warnings(),
77        warning::SetWriter::new(warnings)
78    );
79}
examples/lint_tariff.rs (line 38)
31fn print_lint_warnings(warnings: &warning::Set<lint::tariff::Warning>) {
32    if warnings.is_empty() {
33        return;
34    }
35
36    eprintln!(
37        "WARN: {} warnings from the linting:\n {}",
38        warnings.len_warnings(),
39        warning::SetWriter::new(warnings)
40    );
41}
examples/price_cdr_with_unknown_version.rs (line 103)
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97    if warnings.is_empty() {
98        return;
99    }
100
101    eprintln!(
102        "WARN: {} warnings from the timezone search",
103        warnings.len_warnings()
104    );
105
106    eprintln!(
107        "WARN: {} warnings from the timezone search:\n {}",
108        warnings.len_warnings(),
109        warning::SetWriter::new(warnings)
110    );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114    eprintln!(
115        "ERR: Unable to price CDR due to error at path `{}`: {}",
116        error.element().path(),
117        error.warning()
118    );
119}
120
121fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
122    if warnings.is_empty() {
123        return;
124    }
125
126    eprintln!(
127        "WARN: {} warnings from the linting:\n {}",
128        warnings.len_warnings(),
129        warning::SetWriter::new(warnings)
130    );
131}
pub fn iter(&self) -> Iter<'_, W>

Return an iterator of Warnings grouped by json::Element.

pub fn path_map(&self) -> BTreeMap<&str, Vec<&W>>

Return a map of json::Element paths to a list of Warning.

This is designed to be used to print out maps of warnings associated with elements. You can use the debug alternate format {:#?} to print the map ‘pretty’ over multiple lines with indentation.

pub fn into_path_map(self) -> BTreeMap<Path, Vec<W>>

Consume the Set and return a map of json::Element paths to a list of Warnings.

This is designed to be used to print out maps of warnings associated with elements.

pub fn path_id_map(&self) -> BTreeMap<&str, Vec<Id>>

Return a map of json::Element paths to a list of Warning ids as Strings.

This is designed to be used to print out maps of warnings associated with elements. You can use the debug alternate format {:#?} to print the map ‘pretty’ over multiple lines with indentation.

Note: This representation is also valid JSON and can be copied directly to a test expectation file.

pub fn path_msg_map(&self) -> BTreeMap<&str, Vec<String>>

Return a map of json::Element paths to a list of Warning messages as Strings.

This is designed to be used to print out maps of warnings associated with elements. You can use the debug alternate format {:#?} to print the map ‘pretty’ over multiple lines with indentation.