SetWriter

Struct SetWriter 

pub struct SetWriter<'caller, W: Warning> { /* private fields */ }
A Display object for writing a set of warnings.

The warnings set is formatted as a tree with element paths on the first level and a list of warning ids on the second.

$path.to.json.[0].field:
  - list_of_warning_ids
  - next_warning_id

$next.path.to.[1].json.field
  - list_of_warning_ids

Implementations

Source

impl<'caller, W: Warning> SetWriter<'caller, W>

pub fn new(warnings: &'caller Set<W>) -> Self

Create a new SetWriter with a default warning id indent of " - ".

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 81)
73fn print_warnings(warnings: &warning::Set<generate::Warning>) {
74    if warnings.is_empty() {
75        return;
76    }
77
78    eprintln!(
79        "WARN: {} warnings from the linting:\n {}",
80        warnings.len_warnings(),
81        warning::SetWriter::new(warnings)
82    );
83}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 79)
71fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
72    if warnings.is_empty() {
73        return;
74    }
75
76    eprintln!(
77        "WARN: {} warnings from the pricing:\n {}",
78        warnings.len_warnings(),
79        warning::SetWriter::new(warnings)
80    );
81}
examples/lint_tariff.rs (line 40)
32fn print_lint_warnings(warnings: &warning::Set<lint::tariff::Warning>) {
33    if warnings.is_empty() {
34        return;
35    }
36
37    eprintln!(
38        "WARN: {} warnings from the linting:\n {}",
39        warnings.len_warnings(),
40        warning::SetWriter::new(warnings)
41    );
42}
examples/price_cdr_with_unknown_version.rs (line 111)
98fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
99    if warnings.is_empty() {
100        return;
101    }
102
103    eprintln!(
104        "WARN: {} warnings from the timezone search",
105        warnings.len_warnings()
106    );
107
108    eprintln!(
109        "WARN: {} warnings from the timezone search:\n {}",
110        warnings.len_warnings(),
111        warning::SetWriter::new(warnings)
112    );
113}
114
115/// Print the `price::Warning` that halted the process to `stderr`.
116fn print_pricing_error(error: &warning::Error<price::Warning>) {
117    eprintln!(
118        "ERR: Unable to price CDR due to error at path `{}`: {}",
119        error.element().path(),
120        error.warning()
121    );
122}
123
124/// Print the `price::Warning`s to `stderr`.
125fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
126    if warnings.is_empty() {
127        return;
128    }
129
130    eprintln!(
131        "WARN: {} warnings from the linting:\n {}",
132        warnings.len_warnings(),
133        warning::SetWriter::new(warnings)
134    );
135}
pub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self

Create a new SetWriter with a custom warning id indent.