pub struct SetWriter<'caller, W: Warning> { /* private fields */ }Expand description
A Display object for writing a set of warnings.
The warnings set is formatted as a tree with element paths on the first level and a list of warning ids on the second.
$path.to.json.[0].field:
- list_of_warning_ids
- next_warning_id
$next.path.to.[1].json.field
- list_of_warning_idsImplementations
Sourceimpl<'caller, W: Warning> SetWriter<'caller, W>
impl<'caller, W: Warning> SetWriter<'caller, W>
Sourcepub fn new(warnings: &'caller Set<W>) -> Self
pub fn new(warnings: &'caller Set<W>) -> Self
Create a new SetWriter with a default warning id indent of " - ".
Examples found in repository?
More examples
examples/price_cdr_with_unknown_version.rs (line 111)
98fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
99 if warnings.is_empty() {
100 return;
101 }
102
103 eprintln!(
104 "WARN: {} warnings from the timezone search",
105 warnings.len_warnings()
106 );
107
108 eprintln!(
109 "WARN: {} warnings from the timezone search:\n {}",
110 warnings.len_warnings(),
111 warning::SetWriter::new(warnings)
112 );
113}
114
115/// Print the `price::Warning` that halted the process to `stderr`.
116fn print_pricing_error(error: &warning::Error<price::Warning>) {
117 eprintln!(
118 "ERR: Unable to price CDR due to error at path `{}`: {}",
119 error.element().path(),
120 error.warning()
121 );
122}
123
124/// Print the `price::Warning`s to `stderr`.
125fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
126 if warnings.is_empty() {
127 return;
128 }
129
130 eprintln!(
131 "WARN: {} warnings from the linting:\n {}",
132 warnings.len_warnings(),
133 warning::SetWriter::new(warnings)
134 );
135}Sourcepub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self
pub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self
Create a new SetWriter with a custom warning id indent.