SetWriter

Struct SetWriter 

pub struct SetWriter<'caller, W: Warning> { /* private fields */ }
A Display object for writing a set of warnings.

The warnings set is formatted as a tree with element paths on the first level and a list of warning ids on the second.

$path.to.json.[0].field:
  - list_of_warning_ids
  - next_warning_id

$next.path.to.[1].json.field
  - list_of_warning_ids

Implementations

Source

impl<'caller, W: Warning> SetWriter<'caller, W>

pub fn new(warnings: &'caller Set<W>) -> Self

Create a new SetWriter with a default warning id indent of " - ".

Examples found in repository?
examples/generate_cdr_from_tariff.rs (line 79)
71fn print_warnings(warnings: &warning::Set<generate::Warning>) {
72    if warnings.is_empty() {
73        return;
74    }
75
76    eprintln!(
77        "WARN: {} warnings from the linting:\n {}",
78        warnings.len_warnings(),
79        warning::SetWriter::new(warnings)
80    );
81}
More examples
Hide additional examples
examples/price_cdr_with_known_version.rs (line 77)
69fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
70    if warnings.is_empty() {
71        return;
72    }
73
74    eprintln!(
75        "WARN: {} warnings from the pricing:\n {}",
76        warnings.len_warnings(),
77        warning::SetWriter::new(warnings)
78    );
79}
examples/lint_tariff.rs (line 39)
31fn print_lint_warnings(warnings: &warning::Set<lint::tariff::Warning>) {
32    if warnings.is_empty() {
33        return;
34    }
35
36    eprintln!(
37        "WARN: {} warnings from the linting:\n {}",
38        warnings.len_warnings(),
39        warning::SetWriter::new(warnings)
40    );
41}
examples/price_cdr_with_unknown_version.rs (line 109)
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97    if warnings.is_empty() {
98        return;
99    }
100
101    eprintln!(
102        "WARN: {} warnings from the timezone search",
103        warnings.len_warnings()
104    );
105
106    eprintln!(
107        "WARN: {} warnings from the timezone search:\n {}",
108        warnings.len_warnings(),
109        warning::SetWriter::new(warnings)
110    );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114    eprintln!(
115        "ERR: Unable to price CDR due to error at path `{}`: {}",
116        error.element().path(),
117        error.warning()
118    );
119}
120
121fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
122    if warnings.is_empty() {
123        return;
124    }
125
126    eprintln!(
127        "WARN: {} warnings from the linting:\n {}",
128        warnings.len_warnings(),
129        warning::SetWriter::new(warnings)
130    );
131}
pub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self

Create a new SetWriter with a custom warning id indent.