pub struct SetWriter<'caller, W: Warning> { /* private fields */ }Expand description
A Display object for writing a set of warnings.
The warnings set is formatted as a tree with element paths on the first level and a list of warning ids on the second.
$path.to.json.[0].field:
- list_of_warning_ids
- next_warning_id
$next.path.to.[1].json.field
- list_of_warning_idsImplementations
Sourceimpl<'caller, W: Warning> SetWriter<'caller, W>
impl<'caller, W: Warning> SetWriter<'caller, W>
Sourcepub fn new(warnings: &'caller Set<W>) -> Self
pub fn new(warnings: &'caller Set<W>) -> Self
Create a new SetWriter with a default warning id indent of " - ".
Examples found in repository?
More examples
examples/price_cdr_with_unknown_version.rs (line 109)
96fn print_timezone_warnings(warnings: &warning::Set<timezone::Warning>) {
97 if warnings.is_empty() {
98 return;
99 }
100
101 eprintln!(
102 "WARN: {} warnings from the timezone search",
103 warnings.len_warnings()
104 );
105
106 eprintln!(
107 "WARN: {} warnings from the timezone search:\n {}",
108 warnings.len_warnings(),
109 warning::SetWriter::new(warnings)
110 );
111}
112
113fn print_pricing_error(error: &warning::Error<price::Warning>) {
114 eprintln!(
115 "ERR: Unable to price CDR due to error at path `{}`: {}",
116 error.element().path(),
117 error.warning()
118 );
119}
120
121fn print_pricing_warnings(warnings: &warning::Set<price::Warning>) {
122 if warnings.is_empty() {
123 return;
124 }
125
126 eprintln!(
127 "WARN: {} warnings from the linting:\n {}",
128 warnings.len_warnings(),
129 warning::SetWriter::new(warnings)
130 );
131}Sourcepub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self
pub fn with_indent(warnings: &'caller Set<W>, indent: &'caller str) -> Self
Create a new SetWriter with a custom warning id indent.